@@ -2,11 +2,6 @@
 ci.ivprobit <- ci.default
 
 
-
-#' @export
-degrees_of_freedom.ivprobit <- degrees_of_freedom.ivFixed
-
-
 #' @export
 standard_error.ivprobit <- function(model, ...) {
   .data_frame(
@@ -20,6 +15,5 @@ standard_error.ivprobit <- function(model, ...) {
 p_value.ivprobit <- p_value.default
 
 
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.ivprobit <- model_parameters.ivFixed
