@@ -8,9 +8,11 @@ test_that("param ordinal", {
   imp <- suppressWarnings(mice::mice(d$amp, m = 2, printFlag = FALSE))
   imp.l <- mice::complete(imp, action = "long")
   model <- list() ## Fit and pool models
-  for (i in 1:2) capture.output({
-    model[[i]] <- nnet::multinom(cyl ~ disp + hp, data = imp.l, subset = .imp == i)
-  })
+  for (i in 1:2) {
+    capture.output({
+      model[[i]] <- nnet::multinom(cyl ~ disp + hp, data = imp.l, subset = .imp == i)
+    })
+  }
   pooled <- mice::pool(model)
 
   mp <- model_parameters(pooled)
